@@ -1,4 +1,4 @@
-# $Id: CONSTANT.pm 1242 2010-03-03 20:37:23Z rvos $
+# $Id: CONSTANT.pm 1302 2010-06-11 15:33:11Z rvos $
 package Bio::Phylo::Util::CONSTANT;
 use strict;
 use Scalar::Util 'blessed';
@@ -41,6 +41,17 @@ BEGIN {
 	looks_like_class   
 	looks_like_instance
 	looks_like_implementor
+	_NS_OWL_
+	_NS_DC_
+	_NS_DCTERMS_
+	_NS_NEXML_
+	_NS_RDF_
+	_NS_RDFS_
+	_NS_XSI_
+	_NS_XSD_
+	_NS_XML_
+	_NS_TWE_
+	_NS_TWA_	
     );
     %EXPORT_TAGS = ( 
         'all'         => [ @EXPORT_OK ],
@@ -82,7 +93,22 @@ BEGIN {
 		    looks_like_instance
 		    looks_like_implementor
         	)
-        ],    
+        ],
+	'namespaces' => [
+	    qw(
+		_NS_OWL_
+		_NS_DC_
+		_NS_DCTERMS_
+		_NS_NEXML_
+		_NS_RDF_
+		_NS_RDFS_
+		_NS_XSI_
+		_NS_XSD_
+		_NS_XML_
+		_NS_TWE_
+		_NS_TWA_
+	    )
+	]
     );
 }
 
@@ -91,6 +117,19 @@ BEGIN {
 # If the result after optimization and constant folding is either a constant 
 # or a lexically-scoped scalar which has no other references, then it will 
 # be used in place of function calls made without & or do."
+
+sub _NS_OWL_     () { 'http://www.w3.org/2002/07/owl#' }
+sub _NS_DC_      () { 'http://purl.org/dc/elements/1.1/contributor' }
+sub _NS_DCTERMS_ () { 'http://purl.org/dc/terms/' }
+sub _NS_NEXML_   () { 'http://www.nexml.org/2009' }
+sub _NS_RDF_     () { 'http://www.w3.org/1999/02/22-rdf-syntax-ns#' }
+sub _NS_RDFS_    () { 'http://www.w3.org/2000/01/rdf-schema#' }
+sub _NS_XSI_     () { 'http://www.w3.org/2001/XMLSchema-instance' }
+sub _NS_XSD_     () { 'http://www.w3.org/2001/XMLSchema#' }
+sub _NS_XML_     () { 'http://www.w3.org/XML/1998/namespace' }
+sub _NS_TWE_     () { 'http://tolweb.org/tree/home.pages/downloadtree.html#elements' }
+sub _NS_TWA_     () { 'http://tolweb.org/tree/home.pages/downloadtree.html#attributes' }
+
 sub _NONE_      () { 1  }
 sub _NODE_      () { 2  }
 sub _TREE_      () { 3  }
@@ -322,7 +361,7 @@ Also see the manual: L<Bio::Phylo::Manual> and L<http://rutgervos.blogspot.com>.
 
 =head1 REVISION
 
- $Id: CONSTANT.pm 1242 2010-03-03 20:37:23Z rvos $
+ $Id: CONSTANT.pm 1302 2010-06-11 15:33:11Z rvos $
 
 =cut
 
